yagamee_rcparams = {
    "font.size": 16,
    "figure.figsize": [
        14.0,
        7.0
    ],
    "xtick.labelsize": "large",
    "ytick.labelsize": "large",
    "axes.labelsize": "large",
    "xtick.direction": "in",
    "ytick.direction": "in",
    "xtick.major.size": 7,
    "ytick.major.size": 7,
    "axes.spines.top": True,
    "axes.spines.right": True,
    "axes.spines.bottom": True,
    "axes.spines.left": True,
    "axes.linewidth": 1.0,
    "legend.borderpad": 0.5,
    "legend.borderaxespad": 1.0,
    "legend.edgecolor": [
        0.2,
        0.2,
        0.2
    ]
}



def init_rcparams():
    import matplotlib
    from yagamee.yagamee_rcparams import yagamee_rcparams
    matplotlib.rcParams.update(yagamee_rcparams)


def init_matplotlib():
    init_rcparams()
    import japanize_matplotlib



from setuptools import setup
from codecs import open
from os import path
import re
package_name = "yagamee"
root_dir = path.abspath(path.dirname(__file__))


def _requirements():
    return [name.rstrip() for name in open(path.join(root_dir, "requirements.txt")).readlines()]


with open(path.join(root_dir, "README.md"), encoding="utf-8") as f:
    long_description = f.read()

with open(path.join(root_dir, package_name, '__init__.py')) as f:
    init_text = f.read()
    version = re.search(
        r'__version__\s*=\s*[\'\"](.+?)[\'\"]', init_text).group(1)

setup(
    name=package_name,
    version=version,
    description="理系大学生のためのレポート作成支援ツール",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/Mya-Mya/yagamee",
    author="Mya-Mya",
    author_email="",
    license="MIT",
    keywords="matplotlib, graphing, report, report-making, university, science",
    packages=[package_name],
    install_requires=_requirements(),
    classifiers=[
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
    ],
)
